@@ -5,19 +5,23 @@ use warnings;
 use Getopt::Std;
 
 my %opts;
-getopts("2", \%opts);
-die("Usage: ls *.las | xargs -i LAdump -cd reads.db {} | da2paf.pl [-2] <(DBdump -rh reads.db)\n") if @ARGV < 1;
+getopts("2n", \%opts);
+die("Usage: ls *.las | xargs -i LAdump -cd reads.db {} | da2paf.pl [-2n] <(DBdump -rh reads.db)\n") if @ARGV < 1;
 my $is_dbl = defined($opts{2});
+my $with_name = defined($opts{n});
 
 warn("Reading sequence lengths...\n");
 my $fn = shift(@ARGV);
 open(FH, $fn) || die;
-my ($id, @len);
+my ($id, $pre, @len, @name);
 while (<FH>) {
 	if (/^R\s(\d+)/) {
 		$id = $1;
-	} elsif (/^L\s\S+\s(\d+)\s(\d+)/) {
-		$len[$id] = $2 - $1;
+	} elsif (/^H\s\S+\s(\S+)/) {
+		$pre = $1;
+	} elsif (/^L\s(\S+)\s(\d+)\s(\d+)/) {
+		$len[$id] = $3 - $2;
+		$name[$id] = "$pre/$1/$2_$3";
 	}
 }
 close(FH);
@@ -33,11 +37,12 @@ while (<>) {
 	} elsif (!$skip && /^D\s(\d+)/) {
 		my $bl = $ae - $ab > $be - $bb? $ae - $ab : $be - $bb;
 		my $ml = $bl - $1;
+		my ($n0, $n1) = $with_name? ($name[$id0], $name[$id1]) : ($id0, $id1);
 		if ($strand eq '+') {
-			print join("\t", $id0, $len[$id0], $ab, $ae, '+', $id1, $len[$id1], $bb, $be, $ml, $bl, 255), "\n";
+			print join("\t", $n0, $len[$id0], $ab, $ae, '+', $n1, $len[$id1], $bb, $be, $ml, $bl, 255), "\n";
 		} else {
 			my $l = $len[$id1];
-			print join("\t", $id0, $len[$id0], $ab, $ae, '-', $id1, $l, $l - $be, $l - $bb, $ml, $bl, 255), "\n";
+			print join("\t", $n0, $len[$id0], $ab, $ae, '-', $n1, $l, $l - $be, $l - $bb, $ml, $bl, 255), "\n";
 		}
 	}
 }
